#ifndef _GAP_HEADERS_H_QEHJ
#define _GAP_HEADERS_H_QEHJ

#include <stdlib.h>
#include <stddef.h>
#include "gmp.h"
extern "C" {
#include "compiled.h"
}

#endif
